import { Params } from "react-router-dom";
import Api from "../../helpers/Api";
import { IFlight, ISeat, ISeats } from "../Dashboard/CustomerDashboard";

export interface IBookingInfo {
  id: number;
  flightId: number;
  userId: number;
  bookingClass: number;
  seatId?: number;
}

export interface IFullBookingInfo {
  booking: IBookingInfo;
  seats: ISeats;
}

interface ISeatBookingResponse {
  bookedSeat: boolean;
  message: string;
}

export interface IBookingData {
  flight: IFlight;
  seat: ISeat;
}

export async function GetBookingInformation({
  params,
}: {
  params: Params;
}): Promise<IFullBookingInfo> {
  const url = `Booking/${params.id}`;
  try {
    const bookingCall = Api.get(`${url}`, { withCredentials: true });
    const seatsCall = Api.get(`Flight/${params.id}/seats`, { withCredentials: true });

    const [booking, seats] = await Promise.all([bookingCall, seatsCall]);

    return {
      booking: booking.data,
      seats: seats.data
    };
  } catch (error) {
    throw error;
  }
}

export async function GetBookingFlight(
  flightId?: number
): Promise<IFlight | undefined> {
  if (!flightId) {
    return undefined;
  }
  try {
    const flights = await Api.get(`Flight/${flightId}`, {
      withCredentials: true,
    });

    return flights.data as IFlight;
  } catch (error) {
    throw error;
  }
}

export async function GetBookingSeat(seatId: number): Promise<ISeat> {
  try {
    const seat = await Api.get(`Seat/${seatId}`, {
      withCredentials: true,
    });

    return seat.data as ISeat;
  } catch (error) {
    throw error;
  }
}

export async function GetFullBookingData(
  flightId: number,
  seatId: number
): Promise<IBookingData> {
  try {
    const flight = Api.get(`Flight/${flightId}`, { withCredentials: true });
    const seats = Api.get(`Seat/${seatId}/seats`, {
      withCredentials: true,
    });
    const [fdata, sdata] = await Promise.all([flight, seats]);
    return {
      flight: fdata.data,
      seat: sdata.data,
    };
  } catch (error) {
    throw error;
  }
}

export async function updateSeat(booking: number, seatId: number) {
  return Api.put<ISeatBookingResponse>(`Booking/${booking}`, { SeatId: seatId }, { withCredentials: true });
}
